@@ -141,8 +141,11 @@ location_new_from_xml (GWeatherParser *parser, GWeatherLocationLevel level,
     loc->level = level;
     loc->ref_count = 1;
     loc->msgctxt = NULL;
-    if (level == GWEATHER_LOCATION_WORLD)
+    if (level == GWEATHER_LOCATION_WORLD) {
 	loc->metar_code_cache = g_hash_table_ref (parser->metar_code_cache);
+	loc->country_code_cache = g_hash_table_ref (parser->country_code_cache);
+	loc->timezone_cache = g_hash_table_ref (parser->timezone_cache);
+    }
     children = g_ptr_array_new ();
 
     if (xmlTextReaderRead (parser->xml) != 1)
@@ -275,6 +278,13 @@ location_new_from_xml (GWeatherParser *parser, GWeatherLocationLevel level,
 	    g_hash_table_replace (parser->metar_code_cache, loc->station_code, b);
     }
 
+    if (level == GWEATHER_LOCATION_COUNTRY) {
+	if (loc->country_code) {
+	    g_hash_table_replace (parser->country_code_cache, loc->country_code,
+				  gweather_location_ref (loc));
+	}
+    }
+
     if (children->len) {
 	if (level == GWEATHER_LOCATION_CITY)
 	    g_ptr_array_sort_with_data (children, sort_locations_by_distance, loc);
@@ -411,6 +421,8 @@ gweather_location_unref (GWeatherLocation *loc)
 	g_hash_table_unref (loc->metar_code_cache);
     if (loc->timezone_cache)
 	g_hash_table_unref (loc->timezone_cache);
+    if (loc->country_code_cache)
+	g_hash_table_unref (loc->country_code_cache);
 
     g_slice_free (GWeatherLocation, loc);
 }
@@ -1125,7 +1137,7 @@ _gweather_location_update_weather_location (GWeatherLocation *gloc,
  *
  * See gweather_location_deserialize() to recover a stored #GWeatherLocation.
  *
- * Returns: a weather station level #GWeatherLocation for @station_code,
+ * Returns: (transfer none): a weather station level #GWeatherLocation for @station_code,
  *          or %NULL if none exists in the database.
  */
 GWeatherLocation *
@@ -1138,6 +1150,23 @@ gweather_location_find_by_station_code (GWeatherLocation *world,
     return l ? l->data : NULL;
 }
 
+/**
+ * gweather_location_find_by_country_code:
+ * @world: a #GWeatherLocation at the world
+ * @country_code: a country code
+ *
+ * Retrieves the country identified by the specified ISO 3166 code,
+ * if present in the database.
+ *
+ * Returns: (transfer none): a country level #GWeatherLocation, or %NULL.
+ */
+GWeatherLocation *
+gweather_location_find_by_country_code (GWeatherLocation *world,
+                                        const gchar      *country_code)
+{
+	return g_hash_table_lookup (world->country_code_cache, country_code);
+}
+
 /**
  * gweather_location_equal:
  * @one: a #GWeatherLocation
