@@ -29,6 +29,7 @@
 #include <time.h>
 #include <unistd.h>
 #include <langinfo.h>
+#include <errno.h>
 
 #include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
@@ -111,10 +112,10 @@ _weather_location_free (WeatherLocation *location)
 
 static const gchar *wind_direction_str[] = {
     N_("Variable"),
-    N_("North"), N_("North - NorthEast"), N_("Northeast"), N_("East - NorthEast"),
-    N_("East"), N_("East - Southeast"), N_("Southeast"), N_("South - Southeast"),
-    N_("South"), N_("South - Southwest"), N_("Southwest"), N_("West - Southwest"),
-    N_("West"), N_("West - Northwest"), N_("Northwest"), N_("North - Northwest")
+    N_("North"), N_("North — NorthEast"), N_("Northeast"), N_("East — NorthEast"),
+    N_("East"), N_("East — Southeast"), N_("Southeast"), N_("South — Southeast"),
+    N_("South"), N_("South — Southwest"), N_("Southwest"), N_("West — Southwest"),
+    N_("West"), N_("West — Northwest"), N_("Northwest"), N_("North — Northwest")
 };
 
 const gchar *
@@ -472,6 +473,7 @@ get_cache (void)
 				 "libgweather", NULL);
 
     if (g_mkdir_with_parents (filename, 0700) < 0) {
+	g_warning ("Failed to create libgweather cache directory: %s. Check your XDG_CACHE_HOME setting!", strerror (errno));
 	g_free (filename);
 	return NULL;
     }
@@ -505,12 +507,14 @@ ref_session (void)
     session = soup_session_new ();
 
     cache = get_cache ();
-    soup_session_add_feature (session, SOUP_SESSION_FEATURE (cache));
-    g_object_set_data_full (G_OBJECT (session), "libgweather-cache", g_object_ref (cache),
-			    (GDestroyNotify) dump_and_unref_cache);
+    if (cache != NULL) {
+	soup_session_add_feature (session, SOUP_SESSION_FEATURE (cache));
+	g_object_set_data_full (G_OBJECT (session), "libgweather-cache", g_object_ref (cache),
+			        (GDestroyNotify) dump_and_unref_cache);
 
-    soup_cache_load (cache);
-    g_object_unref (cache);
+	soup_cache_load (cache);
+	g_object_unref (cache);
+    }
 
     static_session = session;
     g_object_add_weak_pointer (G_OBJECT (session), (void**) &static_session);
